.. _contrib:

Huey Extensions
===============

The ``huey.contrib`` package contains modules that provide extra functionality
beyond the core APIs.

.. include:: mini.rst

.. include:: django.rst

.. include:: asyncio.rst
